==> abtesting-hooks-1.11.0.tgz: package/lib/useExperimentCore/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";

/* eslint-disable react-hooks/exhaustive-deps */
import { useEffect, useState } from 'react';
import OptimizelyX from './optimizely-x';
import { storage } from './storage';

var noop = function noop() {};

export default (function (params) {
  var experimentId = params.experimentId,
      forceActivation = params.forceActivation,
      _params$forceActivati = params.forceActivationDelay,
      forceActivationDelay = _params$forceActivati === void 0 ? 1000 : _params$forceActivati,
      forceVariation = params.forceVariation,
      _params$onActivation = params.onActivation,
      onActivation = _params$onActivation === void 0 ? noop : _params$onActivation,
      rawVariations = params.variations; // parse variations config

  var variations = rawVariations.map(function (raw) {
    if (typeof raw === 'object') return raw;
    return {
      id: raw
    }; // make an object from a naked id
  }); // get default variation

  var defaultVariation = variations.find(function (variation) {
    return variation.isDefault;
  });
  var defaultVariationId = defaultVariation ? defaultVariation.id : null;

  var getNameFromVariation = function getNameFromVariation(variation) {
    // variationName exists in object
    if (variation.name) return variation.name; // otherwise, use an alphabet letter based on variation position

    var variationIndex = variations.indexOf(variation);
    return String.fromCharCode(65 + variationIndex); // A, B, C, D, ...
  };

  var checkVariationId = function checkVariationId(variationId) {
    var checkedVariation = variationId && variations.find(function (variation) {
      return (// name or id are both valid ways to force a variation
        variationId === getNameFromVariation(variation) || variationId === variation.id
      );
    });
    return checkedVariation ? checkedVariation.id : null;
  };

  var getNameFromVariationId = function getNameFromVariationId(variationId) {
    return getNameFromVariation(variations.find(function (variation) {
      return variationId === variation.id;
    }));
  };

  var getFlagsFromVariationId = function getFlagsFromVariationId(variationId) {
    return variations.reduce(function (obj, variation) {
      var _extends2;

      var variationName = getNameFromVariation(variation); // capitalize variation name in order to get a well-formed camel case key
      // i. e. for a name 'foo' → isVariationFoo

      var capitalizedVariationName = variationName.charAt(0).toUpperCase() + variationName.slice(1);
      return _extends({}, obj, (_extends2 = {}, _extends2["isVariation" + capitalizedVariationName] = variationId === variation.id, _extends2));
    }, {});
  };

  var buildExperimentState = function buildExperimentState(_ref) {
    var variationId = _ref.variationId,
        _ref$active = _ref.active,
        active = _ref$active === void 0 ? false : _ref$active;
    var variationName = getNameFromVariationId(variationId);
    return _extends({}, params, {
      isActive: active,
      isDefault: variationId === defaultVariationId,
      isVariation: variationId !== defaultVariationId,
      isWrapped: true,
      variationId: variationId,
      variationName: variationName
    }, getFlagsFromVariationId(variationId));
  };

  var initialVariationId = checkVariationId(params.forceVariation) || defaultVariationId; // set state which will be used to provide context

  var initialState = buildExperimentState({
    variationId: initialVariationId
  });

  var _useState = useState(initialState),
      state = _useState[0],
      setState = _useState[1];

  var parseVariationId = function parseVariationId(rawVariationId) {
    var numberVariationId = Number(rawVariationId);
    return !isNaN(numberVariationId) ? numberVariationId : rawVariationId;
  };

  var activationHandler = function activationHandler(rawVariationId) {
    var variationId = parseVariationId(rawVariationId);
    var newExperimentState = buildExperimentState(_extends({}, state, {
      variationId: variationId,
      active: true
    }));
    onActivation(newExperimentState);
    return setState(newExperimentState);
  };

  var logWatchOutMessage = function logWatchOutMessage(message) {
    // eslint-disable-next-line no-console
    if (process.env.NODE_ENV !== 'test') console.warn(message);
  };

  useEffect(function () {
    if (process.env.NODE_ENV !== 'production') {
      var getMessageForParam = function getMessageForParam(param) {
        return "[ExperimentCore] Watch out!! Optimizely response will be ignored because the " + param + " param.";
      };
      /*
       * [Fake activation]
       * Activate variation via `forceActivation` API flag
       */


      if (forceActivation) {
        setTimeout(function () {
          return activationHandler(checkVariationId(forceActivation));
        }, forceActivationDelay);
        logWatchOutMessage(getMessageForParam('forceActivation'));
        return;
      }
      /*
       * [Fake activation]
       * Activate variation via `forceVariation` API flag
       */


      if (forceVariation) {
        logWatchOutMessage(getMessageForParam('forceVariation'));
        return;
      }
    }
    /*
     * [Fake activation]
     * - Activate variation via `forceExperiment` browser query flag.
     * - Also sets the flag into session storage to extend the effect during
     *   the tab session.
     */


    if (typeof URLSearchParams !== 'undefined') {
      var sessionStorageKey = "_suiAbtestingForceExperiment_" + state.experimentId;
      var urlParams = new URLSearchParams(window.location.search);
      var forceExperimentFromQueryParam = urlParams.get('forceExperiment');
      var forceExperimentFromSessionStorage = storage({
        key: sessionStorageKey
      });

      var splitNames = function splitNames(forceExperiment) {
        return forceExperiment.split('|');
      };

      var getForceExperimentToBeApplied = function getForceExperimentToBeApplied() {
        if (forceExperimentFromQueryParam && forceExperimentFromSessionStorage) {
          // When both query param and session storage entry are present,
          // query param has preference BUT only if it's the same name,
          // so it can override session storage entry.
          var _splitNames = splitNames(forceExperimentFromQueryParam),
              nameFromQP = _splitNames[0];

          var _splitNames2 = splitNames(forceExperimentFromSessionStorage),
              nameFromSS = _splitNames2[0];

          return nameFromQP === nameFromSS ? forceExperimentFromQueryParam : forceExperimentFromSessionStorage;
        } // Otherwise, whether any of them are present preference rule is simple


        return forceExperimentFromQueryParam || forceExperimentFromSessionStorage;
      };

      var forceExperiment = getForceExperimentToBeApplied();

      if (forceExperiment) {
        var _splitNames3 = splitNames(forceExperiment),
            experimentName = _splitNames3[0],
            variationName = _splitNames3[1];

        if (!experimentName || !variationName || state.name !== experimentName) {
          return;
        } // fake activation is ready to trigger


        setTimeout(function () {
          return activationHandler(checkVariationId(variationName));
        }, forceActivationDelay);
        storage({
          method: 'setItem',
          key: sessionStorageKey,
          value: forceExperiment
        });
        return;
      }
    }
    /*
     * [Natural activation]
     * Activate the right variation via Optimizely criteria
     */


    OptimizelyX.addActivationListener(experimentId, activationHandler);
    return function () {
      OptimizelyX.removeActivationListener(experimentId, activationHandler);
    };
  }, []);
  return {
    experimentData: state
  };
});

==> abtesting-hooks-1.12.0.tgz: package/lib/useExperimentCore/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
/* eslint-disable react-hooks/exhaustive-deps */
import { useEffect, useState } from 'react';
import OptimizelyX from './optimizely-x';
import { storage } from './storage';
var noop = function noop() {};
export default (function (params) {
  var experimentId = params.experimentId,
    forceActivation = params.forceActivation,
    _params$forceActivati = params.forceActivationDelay,
    forceActivationDelay = _params$forceActivati === void 0 ? 1000 : _params$forceActivati,
    forceVariation = params.forceVariation,
    _params$onActivation = params.onActivation,
    onActivation = _params$onActivation === void 0 ? noop : _params$onActivation,
    rawVariations = params.variations;

  // parse variations config
  var variations = rawVariations.map(function (raw) {
    if (typeof raw === 'object') return raw;
    return {
      id: raw
    }; // make an object from a naked id
  });

  // get default variation
  var defaultVariation = variations.find(function (variation) {
    return variation.isDefault;
  });
  var defaultVariationId = defaultVariation ? defaultVariation.id : null;
  var getNameFromVariation = function getNameFromVariation(variation) {
    // variationName exists in object
    if (variation.name) return variation.name;

    // otherwise, use an alphabet letter based on variation position
    var variationIndex = variations.indexOf(variation);
    return String.fromCharCode(65 + variationIndex); // A, B, C, D, ...
  };

  var checkVariationId = function checkVariationId(variationId) {
    var checkedVariation = variationId && variations.find(function (variation) {
      return (
        // name or id are both valid ways to force a variation
        variationId === getNameFromVariation(variation) || variationId === variation.id
      );
    });
    return checkedVariation ? checkedVariation.id : null;
  };
  var getNameFromVariationId = function getNameFromVariationId(variationId) {
    return getNameFromVariation(variations.find(function (variation) {
      return variationId === variation.id;
    }));
  };
  var getFlagsFromVariationId = function getFlagsFromVariationId(variationId) {
    return variations.reduce(function (obj, variation) {
      var _extends2;
      var variationName = getNameFromVariation(variation);

      // capitalize variation name in order to get a well-formed camel case key
      // i. e. for a name 'foo' → isVariationFoo
      var capitalizedVariationName = variationName.charAt(0).toUpperCase() + variationName.slice(1);
      return _extends({}, obj, (_extends2 = {}, _extends2["isVariation" + capitalizedVariationName] = variationId === variation.id, _extends2));
    }, {});
  };
  var buildExperimentState = function buildExperimentState(_ref) {
    var variationId = _ref.variationId,
      _ref$active = _ref.active,
      active = _ref$active === void 0 ? false : _ref$active;
    var variationName = getNameFromVariationId(variationId);
    return _extends({}, params, {
      isActive: active,
      isDefault: variationId === defaultVariationId,
      isVariation: variationId !== defaultVariationId,
      isWrapped: true,
      variationId: variationId,
      variationName: variationName
    }, getFlagsFromVariationId(variationId));
  };
  var initialVariationId = checkVariationId(params.forceVariation) || defaultVariationId;

  // set state which will be used to provide context
  var initialState = buildExperimentState({
    variationId: initialVariationId
  });
  var _useState = useState(initialState),
    state = _useState[0],
    setState = _useState[1];
  var parseVariationId = function parseVariationId(rawVariationId) {
    var numberVariationId = Number(rawVariationId);
    return !isNaN(numberVariationId) ? numberVariationId : rawVariationId;
  };
  var activationHandler = function activationHandler(rawVariationId) {
    var variationId = parseVariationId(rawVariationId);
    var newExperimentState = buildExperimentState(_extends({}, state, {
      variationId: variationId,
      active: true
    }));
    onActivation(newExperimentState);
    return setState(newExperimentState);
  };
  var logWatchOutMessage = function logWatchOutMessage(message) {
    // eslint-disable-next-line no-console
    if (process.env.NODE_ENV !== 'test') console.warn(message);
  };
  useEffect(function () {
    if (process.env.NODE_ENV !== 'production') {
      var getMessageForParam = function getMessageForParam(param) {
        return "[ExperimentCore] Watch out!! Optimizely response will be ignored because the " + param + " param.";
      };

      /*
       * [Fake activation]
       * Activate variation via `forceActivation` API flag
       */
      if (forceActivation) {
        setTimeout(function () {
          return activationHandler(checkVariationId(forceActivation));
        }, forceActivationDelay);
        logWatchOutMessage(getMessageForParam('forceActivation'));
        return;
      }

      /*
       * [Fake activation]
       * Activate variation via `forceVariation` API flag
       */
      if (forceVariation) {
        logWatchOutMessage(getMessageForParam('forceVariation'));
        return;
      }
    }

    /*
     * [Fake activation]
     * - Activate variation via `forceExperiment` browser query flag.
     * - Also sets the flag into session storage to extend the effect during
     *   the tab session.
     */
    if (typeof URLSearchParams !== 'undefined') {
      var sessionStorageKey = "_suiAbtestingForceExperiment_" + state.experimentId;
      var urlParams = new URLSearchParams(window.location.search);
      var forceExperimentFromQueryParam = urlParams.get('forceExperiment');
      var forceExperimentFromSessionStorage = storage({
        key: sessionStorageKey
      });
      var splitNames = function splitNames(forceExperiment) {
        return forceExperiment.split('|');
      };
      var getForceExperimentToBeApplied = function getForceExperimentToBeApplied() {
        if (forceExperimentFromQueryParam && forceExperimentFromSessionStorage) {
          // When both query param and session storage entry are present,
          // query param has preference BUT only if it's the same name,
          // so it can override session storage entry.
          var _splitNames = splitNames(forceExperimentFromQueryParam),
            nameFromQP = _splitNames[0];
          var _splitNames2 = splitNames(forceExperimentFromSessionStorage),
            nameFromSS = _splitNames2[0];
          return nameFromQP === nameFromSS ? forceExperimentFromQueryParam : forceExperimentFromSessionStorage;
        }
        // Otherwise, whether any of them are present preference rule is simple
        return forceExperimentFromQueryParam || forceExperimentFromSessionStorage;
      };
      var forceExperiment = getForceExperimentToBeApplied();
      if (forceExperiment) {
        var _splitNames3 = splitNames(forceExperiment),
          experimentName = _splitNames3[0],
          variationName = _splitNames3[1];
        if (!experimentName || !variationName || state.name !== experimentName) {
          return;
        }

        // fake activation is ready to trigger
        setTimeout(function () {
          return activationHandler(checkVariationId(variationName));
        }, forceActivationDelay);
        storage({
          method: 'setItem',
          key: sessionStorageKey,
          value: forceExperiment
        });
        return;
      }
    }

    /*
     * [Natural activation]
     * Activate the right variation via Optimizely criteria
     */
    OptimizelyX.addActivationListener(experimentId, activationHandler);
    return function () {
      OptimizelyX.removeActivationListener(experimentId, activationHandler);
    };
  }, []);
  return {
    experimentData: state
  };
});
